@@ -4,7 +4,7 @@
 <?php
 if ($fID > 0) {
     $fo = File::getByID($fID);
-    if ($fo->isError()) {
+   if (!is_object($fo)) {
         unset($fo);
     }
 }
