@@ -8,17 +8,20 @@ use Concrete\Core\File\Image\Thumbnail\Thumbnail;
 use Concrete\Core\File\Image\Thumbnail\Type\Type;
 use Concrete\Core\File\Image\Thumbnail\Type\Version as ThumbnailTypeVersion;
 use Concrete\Core\File\Type\TypeList as FileTypeList;
+use Concrete\Core\Http\FlysystemFileResponse;
 use Concrete\Flysystem\AdapterInterface;
 use Concrete\Flysystem\FileNotFoundException;
 use Core;
+use Database;
 use Events;
 use FileAttributeKey;
 use Imagine\Exception\InvalidArgumentException as ImagineInvalidArgumentException;
 use Imagine\Image\ImageInterface;
-use Loader;
 use Page;
 use Permissions;
 use stdClass;
+use Symfony\Component\HttpFoundation\Response;
+use Symfony\Component\HttpFoundation\ResponseHeaderBag;
 use User;
 use View;
 
@@ -28,12 +31,14 @@ use View;
  */
 class Version
 {
-
     const UT_REPLACE_FILE = 1;
     const UT_TITLE = 2;
     const UT_DESCRIPTION = 3;
     const UT_TAGS = 4;
     const UT_EXTENDED_ATTRIBUTE = 5;
+    const UT_CONTENTS = 6;
+    const UT_RENAME = 7;
+
     /**
      * /* @Id
      * @ManyToOne(targetEntity="File", inversedBy="versions")
@@ -123,8 +128,8 @@ class Version
         $fvTags = (isset($data['fvTags'])) ? Version::cleanTags($data['fvTags']) : '';
         $fvIsApproved = (isset($data['fvIsApproved'])) ? $data['fvIsApproved'] : '1';
 
-        $db = Loader::db();
-        $dh = Loader::helper('date');
+        $db = Database::get();
+        $dh = Core::make('helper/date');
         $date = new Carbon($dh->getOverridableNow());
 
         $fv = new static();
@@ -141,7 +146,7 @@ class Version
         $fv->file = $file;
         $fv->fvID = 1;
 
-        $em = Loader::db()->getEntityManager();
+        $em = Database::get()->getEntityManager();
         $em->persist($fv);
         $em->flush();
 
@@ -220,7 +225,7 @@ class Version
 
     public function clearAttribute($ak)
     {
-        $db = Loader::db();
+        $db = Database::get();
         $cav = $this->getAttributeValueObject($ak);
         if (is_object($cav)) {
             $cav->delete();
@@ -231,7 +236,7 @@ class Version
 
     public function getAttributeValueObject($ak, $createIfNotFound = false)
     {
-        $db = Loader::db();
+        $db = Database::get();
         $av = false;
         $v = array($this->getFileID(), $this->getFileVersionID(), $ak->getAttributeKeyID());
         $avID = $db->GetOne("SELECT avID FROM FileAttributeValues WHERE fID = ? AND fvID = ? AND akID = ?", $v);
@@ -281,8 +286,7 @@ class Version
      */
     public function delete($deleteFilesAndThumbnails = false)
     {
-
-        $db = Loader::db();
+        $db = Database::get();
 
         $db->Execute("DELETE FROM FileAttributeValues WHERE fID = ? AND fvID = ?", array($this->getFileID(), $this->fvID));
         $db->Execute("DELETE FROM FileVersionLog WHERE fID = ? AND fvID = ?", array($this->getFileID(), $this->fvID));
@@ -345,7 +349,7 @@ class Version
 
     public function getSize()
     {
-        return Loader::helper('number')->formatSize($this->fvSize, 'KB');
+        return Core::make('helper/number')->formatSize($this->fvSize, 'KB');
     }
 
     public function getFullSize()
@@ -372,7 +376,7 @@ class Version
      *
      * @return string date formated like: 2009-01-01 00:00:00
      */
-    function getDateAdded()
+    public function getDateAdded()
     {
         return $this->fvDateAdded;
     }
@@ -387,7 +391,7 @@ class Version
      */
     public function duplicate()
     {
-        $db = Loader::db();
+        $db = Database::get();
         $em = $db->getEntityManager();
         $qq = $em->createQuery('SELECT max(v.fvID) FROM \Concrete\Core\File\Version v where v.file = :file');
         $qq->setParameter('file', $this->file);
@@ -436,7 +440,7 @@ class Version
 
     protected function save($flush = true)
     {
-        $em = Loader::db()->getEntityManager();
+        $em = Database::get()->getEntityManager();
         $em->persist($this);
         if ($flush) {
             $em->flush();
@@ -453,7 +457,7 @@ class Version
 
     public function getTypeObject()
     {
-        $fh = Loader::helper('file');
+        $fh = Core::make('helper/file');
         $ext = $fh->getExtension($this->fvFilename);
 
         $ftl = FileTypeList::getType($ext);
@@ -466,7 +470,7 @@ class Version
     public function getVersionLogComments()
     {
         $updates = array();
-        $db = Loader::db();
+        $db = Database::get();
         $ga = $db->GetAll(
             'SELECT fvUpdateTypeID, fvUpdateTypeAttributeID FROM FileVersionLog WHERE fID = ? AND fvID = ? ORDER BY fvlID ASC',
             array($this->getFileID(), $this->getFileVersionID())
@@ -485,6 +489,12 @@ class Version
                 case self::UT_TAGS:
                     $updates[] = t('Tags');
                     break;
+                case self::UT_CONTENTS:
+                    $updates[] = t('File Content');
+                    break;
+                case self::UT_RENAME:
+                    $updates[] = t('File Name');
+                    break;
                 case self::UT_EXTENDED_ATTRIBUTE:
                     $val = $db->GetOne(
                         "SELECT akName FROM AttributeKeys WHERE akID = ?",
@@ -516,7 +526,7 @@ class Version
 
     public function logVersionUpdate($updateTypeID, $updateTypeAttributeID = 0)
     {
-        $db = Loader::db();
+        $db = Database::get();
         $db->Execute(
             'INSERT INTO FileVersionLog (fID, fvID, fvUpdateTypeID, fvUpdateTypeAttributeID) VALUES (?, ?, ?, ?)',
             array(
@@ -547,6 +557,45 @@ class Version
         Events::dispatch('on_file_version_update_description', $fe);
     }
 
+    public function rename($filename)
+    {
+        $cf = Core::make('helper/concrete/file');
+        $storage = $this->getFile()->getFileStorageLocationObject();
+        $oldFilename = $this->fvFilename;
+        if (is_object($storage)) {
+            $path = $cf->prefix($this->fvPrefix, $oldFilename);
+            $newPath = $cf->prefix($this->fvPrefix, $filename);
+            $filesystem = $storage->getFileSystemObject();
+            if ($filesystem->has($path)) {
+                $filesystem->rename($path, $newPath);
+            }
+            $this->fvFilename = $filename;
+            if ($this->fvTitle == $oldFilename) {
+                $this->fvTitle = $filename;
+            }
+            $this->logVersionUpdate(self::UT_RENAME);
+            $this->save();
+        }
+    }
+
+    public function updateContents($contents)
+    {
+        $cf = Core::make('helper/concrete/file');
+        $storage = $this->getFile()->getFileStorageLocationObject();
+        if (is_object($storage)) {
+            $path = $cf->prefix($this->fvPrefix, $this->fvFilename);
+            $filesystem = $storage->getFileSystemObject();
+            if ($filesystem->has($path)) {
+                $filesystem->delete($path);
+            }
+            $filesystem->write($path, $contents);
+            $this->logVersionUpdate(self::UT_CONTENTS);
+            $fe = new \Concrete\Core\File\Event\FileVersion($this);
+            Events::dispatch('on_file_version_update_contents', $fe);
+            $this->refreshAttributes();
+        }
+    }
+
     public function updateFile($filename, $prefix)
     {
         $this->fvFilename = $filename;
@@ -572,7 +621,6 @@ class Version
         $fo->reindex();
 
         \Core::make('cache/request')->delete('file/version/approved/' . $this->getFileID());
-
     }
 
     /**
@@ -606,24 +654,16 @@ class Version
     {
         session_write_close();
         $fre = $this->getFileResource();
-        ob_clean();
-        header('Content-type: application/octet-stream');
-        header("Content-Disposition: attachment; filename=\"" . $this->getFilename() . "\"");
-        header('Content-Length: ' . $fre->getSize());
-        header("Pragma: public");
-        header("Expires: 0");
-        header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
-        header("Cache-Control: private", false);
-        header("Content-Transfer-Encoding: binary");
-        header("Content-Encoding: plainbinary");
 
         $fs = $this->getFile()->getFileStorageLocationObject()->getFileSystemObject();
+        $response = new FlysystemFileResponse($fre->getPath(), $fs);
 
-        $stream = $fs->readStream($fre->getPath());
-        $contents = stream_get_contents($stream);
-        fclose($stream);
+        $response->setContentDisposition(ResponseHeaderBag::DISPOSITION_ATTACHMENT);
+        $response->prepare(\Request::getInstance());
 
-        print $contents;
+        ob_end_clean();
+        $response->send();
+        \Core::shutdown();
         exit;
     }
 
@@ -738,7 +778,7 @@ class Version
                 switch ($mimetype) {
                   case 'image/jpeg':
                     $thumbnailType = 'jpeg';
-                    $thumbnailOptions = array('jpeg_quality' => \Config::get('misc.default_jpeg_image_compression'));
+                    $thumbnailOptions = array('jpeg_quality' => \Config::get('concrete.misc.default_jpeg_image_compression'));
                     break;
                   case 'image/png':
                     $thumbnailType = 'png';
@@ -776,7 +816,6 @@ class Version
 
                 unset($thumbnail);
                 unset($filesystem);
-
             }
         } catch (ImagineInvalidArgumentException $e) {
             return false;
@@ -900,10 +939,10 @@ class Version
      */
     public function refreshAttributes($rescanThumbnails = true)
     {
-        $fh = Loader::helper('file');
+        $fh = Core::make('helper/file');
         $ext = $fh->getExtension($this->fvFilename);
         $ftl = FileTypeList::getType($ext);
-        $db = Loader::db();
+        $db = Database::get();
 
         $fsr = $this->getFileResource();
         if (!$fsr->isFile()) {
