@@ -1,4 +1,5 @@
 <?php
+
 namespace Concrete\Core\Multilingual\Page\Section;
 
 use Concrete\Core\Page\Page;
@@ -66,7 +67,7 @@ class Section extends Page
                 $numPlurals = count($localeInfo->categories);
                 $pluralRule = $localeInfo->formula;
                 $pluralCases = array();
-                foreach($localeInfo->categories as $category) {
+                foreach ($localeInfo->categories as $category) {
                     $pluralCases[] = $category->id.'@'.$category->examples;
                 }
             }
@@ -83,45 +84,41 @@ class Section extends Page
             array('cID'),
             true
         );
-
-        // Now we make sure we have multilingual enabled
-        Config::save('concrete.multilingual.enabled', true);
     }
 
     public function unassign()
     {
         $db = Database::get();
         $db->delete('MultilingualSections', array('cID' => $this->getCollectionID()));
-
-        $total = $db->GetOne('select count(*) from MultilingualSections');
-        if ($total < 1) {
-            Config::save('concrete.multilingual.enabled', false);
-        }
     }
 
-    private static function assignPropertiesFromArray($obj, $row) {
+    private static function assignPropertiesFromArray($obj, $row)
+    {
         $obj->msLanguage = $row['msLanguage'];
         $obj->msCountry = $row['msCountry'];
         $obj->msNumPlurals = $row['msNumPlurals'];
         $obj->msPluralRule = $row['msPluralRule'];
         $obj->msPluralCases = array();
-        foreach(explode("\n", $row['msPluralCases']) as $line) {
+        foreach (explode("\n", $row['msPluralCases']) as $line) {
             list($key, $examples) = explode('@', $line);
             $obj->msPluralCases[$key] = $examples;
         }
     }
 
     /**
-     * returns an instance of  MultilingualSection for the given page ID
+     * Returns an instance of  MultilingualSection for the given page ID.
+     *
      * @param int $cID
-     * @param int $cvID
+     * @param int|string $cvID
+     * @param string $class
+     *
      * @return MultilingualSection|false
      */
     public static function getByID($cID, $cvID = 'RECENT')
     {
         $r = self::isMultilingualSection($cID);
         if ($r) {
-            $obj = parent::getByID($cID, $cvID, '\Concrete\Core\Multilingual\Page\Section\Section');
+            $obj = parent::getByID($cID, $cvID);
             self::assignPropertiesFromArray($obj, $r);
 
             return $obj;
@@ -132,6 +129,7 @@ class Section extends Page
 
     /**
      * @param string $language
+     *
      * @return Section|false
      */
     public static function getByLanguage($language)
@@ -142,7 +140,7 @@ class Section extends Page
             array($language)
         );
         if ($r && is_array($r) && $r['msLanguage']) {
-            $obj = parent::getByID($r['cID'], 'RECENT', '\Concrete\Core\Multilingual\Page\Section\Section');
+            $obj = parent::getByID($r['cID'], 'RECENT');
             self::assignPropertiesFromArray($obj, $r);
 
             return $obj;
@@ -153,6 +151,7 @@ class Section extends Page
 
     /**
      * @param string $language
+     *
      * @return Section|false
      */
     public static function getByLocale($locale)
@@ -164,7 +163,7 @@ class Section extends Page
             array($locale[0], $locale[1])
         );
         if ($r && is_array($r) && $r['msLanguage']) {
-            $obj = parent::getByID($r['cID'], 'RECENT', '\Concrete\Core\Multilingual\Page\Section\Section');
+            $obj = parent::getByID($r['cID'], 'RECENT');
             self::assignPropertiesFromArray($obj, $r);
 
             return $obj;
@@ -174,7 +173,8 @@ class Section extends Page
     }
 
     /**
-     * gets the MultilingualSection object for the current section of the site
+     * Gets the MultilingualSection object for the current section of the site.
+     *
      * @return Section
      */
     public static function getCurrentSection()
@@ -207,22 +207,45 @@ class Section extends Page
 
     /**
      * @param Page $page
+     *
      * @return Section
      */
     public static function getBySectionOfSite($page)
     {
-        // looks at the page, traverses its parents until it finds the proper language
-        $nav = \Core::make('helper/navigation');
-        $pages = $nav->getTrailToCollection($page);
-        $pages = array_reverse($pages);
-        $pages[] = $page;
-        $ids = self::getIDList();
-        $returnID = false;
-        foreach ($pages as $pc) {
-            if (in_array($pc->getCollectionID(), $ids)) {
-                $returnID = $pc->getCollectionID();
+        $identifier = sprintf('/multilingual/section/%s', $page->getCollectionID());
+        $cache = \Core::make('cache/request');
+        $item = $cache->getItem($identifier);
+        if (!$item->isMiss()) {
+            $returnID = $item->get();
+        } else {
+            $item->lock();
+            if ($page->getPageTypeHandle() == STACKS_PAGE_TYPE) {
+                $parent = Page::getByID($page->getCollectionParentID());
+                if ($parent->getCollectionPath() == STACKS_PAGE_PATH) {
+                    // this is the default multilingual section.
+                    return static::getDefaultSection();
+                } else {
+                    // this is a stack category page type
+                    $locale = $parent->getCollectionHandle();
+
+                    return static::getByLocale($locale);
+                }
             }
+            // looks at the page, traverses its parents until it finds the proper language
+            $nav = \Core::make('helper/navigation');
+            $pages = $nav->getTrailToCollection($page);
+            $pages = array_reverse($pages);
+            $pages[] = $page;
+            $ids = self::getIDList();
+            $returnID = false;
+            foreach ($pages as $pc) {
+                if (in_array($pc->getCollectionID(), $ids)) {
+                    $returnID = $pc->getCollectionID();
+                }
+            }
+            $item->set($returnID);
         }
+
         if ($returnID) {
             return static::getByID($returnID);
         }
@@ -243,6 +266,11 @@ class Section extends Page
         return $locale;
     }
 
+    public static function getDefaultSection()
+    {
+        return static::getByLocale(Config::get('concrete.multilingual.default_locale'));
+    }
+
     public function getLanguageText($locale = null)
     {
         try {
@@ -268,8 +296,10 @@ class Section extends Page
     }
 
     /**
-     * Returns the number of plural forms
+     * Returns the number of plural forms.
+     *
      * @return int
+     *
      * @example For Japanese: returns 1
      * @example For English: returns 2
      * @example For French: returns 2
@@ -281,8 +311,10 @@ class Section extends Page
     }
 
     /**
-     * Returns the rule to determine which plural we should use (in gettext notation)
+     * Returns the rule to determine which plural we should use (in gettext notation).
+     *
      * @return string
+     *
      * @example For Japanese: returns '0'
      * @example For English: returns 'n != 1'
      * @example For French: returns 'n > 1'
@@ -294,8 +326,10 @@ class Section extends Page
     }
 
     /**
-     * Returns the plural cases for the language; array keys are the case name, array values are some examples for that case
+     * Returns the plural cases for the language; array keys are the case name, array values are some examples for that case.
+     *
      * @return array
+     *
      * @example For Japanese: returns
      *     'other' => '0~15, 100, 1000, 10000, 100000, 1000000, …'
      * @example For English: returns
@@ -316,7 +350,7 @@ class Section extends Page
 
     public static function registerPage($page)
     {
-        if (Config::get('concrete.multilingual.enabled')) {
+        if (\Core::make('multilingual/detector')->isEnabled()) {
             $db = Database::get();
             $ms = static::getBySectionOfSite($page);
             if (is_object($ms)) {
@@ -333,7 +367,7 @@ class Section extends Page
                 if (!$mpRelationID) {
                     $mpRelationID = 1;
                 } else {
-                    $mpRelationID++;
+                    ++$mpRelationID;
                 }
                 $v = array($mpRelationID, $page->getCollectionID(), $ms->getLanguage(), $ms->getLocale());
                 $db->Execute(
@@ -379,7 +413,7 @@ class Section extends Page
                 if (!$mpRelationID) {
                     $mpRelationID = 1;
                 } else {
-                    $mpRelationID++;
+                    ++$mpRelationID;
                 }
                 $v = array($mpRelationID, $page->getCollectionID(), $ms->getLanguage(), $ms->getLocale());
                 $db->Execute(
@@ -482,7 +516,7 @@ class Section extends Page
                 if (!$mpRelationID) {
                     $mpRelationID = 1;
                 } else {
-                    $mpRelationID++;
+                    ++$mpRelationID;
                 }
 
                 // adding in a check to see if old page was part of a language section or neutral.
@@ -518,6 +552,11 @@ class Section extends Page
         }
     }
 
+    public function isDefaultMultilingualSection()
+    {
+        return $this->getLocale() == Config::get('concrete.multilingual.default_locale');
+    }
+
     public static function isMultilingualSection($cID)
     {
         if (is_object($cID)) {
@@ -584,7 +623,9 @@ class Section extends Page
     }
 
     /**
-     * Receives a page in a different language tree, and tries to return the corresponding page in the current language tree
+     * Receives a page in a different language tree, and tries to return the corresponding page in the current language tree.
+     *
+     * @return int|null
      */
     public function getTranslatedPageID($page)
     {
@@ -607,8 +648,10 @@ class Section extends Page
     }
 
     /**
-     * Loads the translations of this multilingual section
+     * Loads the translations of this multilingual section.
+     *
      * @param bool $untranslatedFirst Set to true to have untranslated strings first
+     *
      * @return \Gettext\Translations
      */
     public function getSectionInterfaceTranslations($untranslatedFirst = false)
