@@ -1,24 +1,17 @@
 <?php
-
 namespace Concrete\Core\User;
 
 use Concrete\Core\Foundation\Object;
-use Loader;
-use Config;
-use Database;
-use UserInfo as CoreUserInfo;
-use Request;
+use Concrete\Core\Http\Request;
+use Concrete\Core\Session\SessionValidatorInterface;
+use Concrete\Core\Support\Facade\Application;
+use Concrete\Core\User\Group\Group;
 use Concrete\Core\Authentication\AuthenticationType;
-use Events;
-use Page;
-use GroupList;
-use Session;
+use Concrete\Core\Page\Page;
+use Concrete\Core\User\Group\GroupList;
 use Hautelook\Phpass\PasswordHash;
 use Concrete\Core\Permission\Access\Entity\Entity as PermissionAccessEntity;
-use Core;
-use Group;
-use \Concrete\Core\User\Point\Action\Action as UserPointAction;
-use View;
+use Concrete\Core\User\Point\Action\Action as UserPointAction;
 
 class User extends Object
 {
@@ -42,14 +35,16 @@ class User extends Object
      */
     public static function getByUserID($uID, $login = false, $cacheItemsOnLogin = true)
     {
-        $db = Database::connection();
+        $app = Application::getFacadeApplication();
+        $db = $app['database']->connection();
+
         $v = array($uID);
         $q = "SELECT uID, uName, uIsActive, uLastOnline, uTimezone, uDefaultLanguage, uLastPasswordChange FROM Users WHERE uID = ? LIMIT 1";
         $r = $db->query($q, $v);
         $row = $r ? $r->FetchRow() : null;
         $nu = null;
         if ($row) {
-            $nu = new User();
+            $nu = new self();
             $nu->setPropertiesFromArray($row);
             $nu->uGroups = $nu->_getUserGroups(true);
             $nu->superUser = ($nu->getUserID() == USER_SUPER_ID);
@@ -69,27 +64,33 @@ class User extends Object
      */
     public function loginByUserID($uID)
     {
-        return User::getByUserID($uID, true);
+        return self::getByUserID($uID, true);
     }
 
     public static function isLoggedIn()
     {
-        $session = Core::make('session');
+        $app = Application::getFacadeApplication();
+        $session = $app['session'];
 
-        return $session->has('uID') && $session->get('uID') > 0 && $session->has('uName')
-            && $session->get('uName') != '' && $session->has('uLastPasswordChange');
+        return $session->has('uID') && $session->get('uID') > 0;
     }
 
     public function checkLogin()
     {
-        $session = Core::make('session');
-        $aeu = Config::get('concrete.misc.access_entity_updated');
+        $app = Application::getFacadeApplication();
+        $session = $app['session'];
+        $config = $app['config'];
+
+        $aeu = $config->get('concrete.misc.access_entity_updated');
         if ($aeu && $aeu > $session->get('accessEntitiesUpdated')) {
-            User::refreshUserGroups();
+            self::refreshUserGroups();
         }
 
+        $app->make('Concrete\Core\Session\SessionValidatorInterface')->handleSessionValidation($session);
+
         if ($session->get('uID') > 0) {
-            $db = Loader::db();
+            $db = $app['database']->connection();
+
             $row = $db->GetRow("select uID, uIsActive, uLastPasswordChange from Users where uID = ? and uName = ?", array($session->get('uID'), $session->get('uName')));
             $checkUID = (isset($row['uID'])) ? ($row['uID']) : (false);
 
@@ -106,7 +107,6 @@ class User extends Object
 
                 $session->set('uOnlineCheck', time());
                 if (($session->get('uOnlineCheck') - $session->get('uLastOnline') > (ONLINE_NOW_TIMEOUT / 2))) {
-                    $db = Loader::db();
                     $db->query("update Users set uLastOnline = ? where uID = ?", array($session->get('uOnlineCheck'), $this->uID));
                     $session->set('uLastOnline', $session->get('uOnlineCheck'));
                 }
@@ -118,9 +118,18 @@ class User extends Object
         }
     }
 
+    public function getUserInfoObject()
+    {
+        return UserInfo::getByID($this->uID);
+    }
+
     public function __construct()
     {
+        $app = Application::getFacadeApplication();
         $args = func_get_args();
+        $session = $app['session'];
+        $config = $app['config'];
+
 
         if (isset($args[1])) {
             // first, we check to see if the username and password match the admin username and password
@@ -128,23 +137,25 @@ class User extends Object
 
             $username = $args[0];
             $password = $args[1];
-            if (!$args[2]) {
-                Session::remove('uGroups');
-                Session::remove('accessEntities');
+            $disableLogin = isset($args[2]) ? (bool) $args[2] : false;
+            if (!$disableLogin) {
+                $session->remove('uGroups');
+                $session->remove('accessEntities');
             }
             $v = array($username);
-            if (Config::get('concrete.user.registration.email_registration')) {
+            if ($config->get('concrete.user.registration.email_registration')) {
                 $q = "select uID, uName, uIsActive, uIsValidated, uTimezone, uDefaultLanguage, uPassword, uLastPasswordChange from Users where uEmail = ?";
             } else {
                 $q = "select uID, uName, uIsActive, uIsValidated, uTimezone, uDefaultLanguage, uPassword, uLastPasswordChange from Users where uName = ?";
             }
-            $db = Loader::db();
+
+            $db = $app->make('Concrete\Core\Database\Connection\Connection');
             $r = $db->query($q, $v);
             if ($r) {
                 $row = $r->fetchRow();
-                $pw_is_valid_legacy = (defined('PASSWORD_SALT') && User::legacyEncryptPassword($password) == $row['uPassword']);
+                $pw_is_valid_legacy = ($config->get('concrete.user.password.legacy_salt') && self::legacyEncryptPassword($password) == $row['uPassword']);
                 $pw_is_valid = $pw_is_valid_legacy || $this->getUserPasswordHasher()->checkPassword($password, $row['uPassword']);
-                if ($row['uID'] && $row['uIsValidated'] === '0' && Config::get('concrete.user.registration.validate_email')) {
+                if ($row['uID'] && $row['uIsValidated'] === '0' && $config->get('concrete.user.registration.validate_email')) {
                     $this->loadError(USER_NON_VALIDATED);
                 } elseif ($row['uID'] && $row['uIsActive'] && $pw_is_valid) {
                     $this->uID = $row['uID'];
@@ -153,14 +164,14 @@ class User extends Object
                     $this->uTimezone = $row['uTimezone'];
                     $this->uDefaultLanguage = $row['uDefaultLanguage'];
                     $this->uLastPasswordChange = $row['uLastPasswordChange'];
-                    $this->uGroups = $this->_getUserGroups($args[2]);
+                    $this->uGroups = $this->_getUserGroups($disableLogin);
                     if ($row['uID'] == USER_SUPER_ID) {
                         $this->superUser = true;
                     } else {
                         $this->superUser = false;
                     }
                     $this->recordLogin();
-                    if (!$args[2]) {
+                    if (!$disableLogin) {
                         $this->persist();
                     }
                 } elseif ($row['uID'] && !$row['uIsActive']) {
@@ -200,14 +211,14 @@ class User extends Object
                     }
                     $this->uTimezone = $ux->getUserTimezone();
                 }
-            } elseif (Session::has('uID')) {
-                $this->uID = Session::get('uID');
-                $this->uName = Session::get('uName');
-                $this->uTimezone = Session::get('uTimezone');
-                if (Session::has('uDefaultLanguage')) {
-                    $this->uDefaultLanguage = Session::get('uDefaultLanguage');
+            } elseif ($session->has('uID')) {
+                $this->uID = $session->get('uID');
+                $this->uName = $session->get('uName');
+                $this->uTimezone = $session->get('uTimezone');
+                if ($session->has('uDefaultLanguage')) {
+                    $this->uDefaultLanguage = $session->get('uDefaultLanguage');
                 }
-                $this->superUser = (Session::get('uID') == USER_SUPER_ID) ? true : false;
+                $this->superUser = ($session->get('uID') == USER_SUPER_ID) ? true : false;
             } else {
                 $this->uID = null;
                 $this->uName = null;
@@ -217,7 +228,7 @@ class User extends Object
             }
             $this->uGroups = $this->_getUserGroups();
             if (!isset($args[2]) && !$req->hasCustomRequestUser()) {
-                Session::set('uGroups', $this->uGroups);
+                $session->set('uGroups', $this->uGroups);
             }
         }
 
@@ -226,18 +237,21 @@ class User extends Object
 
     public function recordLogin()
     {
-        $db = Loader::db();
+        $app = Application::getFacadeApplication();
+        $db = $app['database']->connection();
         $uLastLogin = $db->getOne("select uLastLogin from Users where uID = ?", array($this->uID));
 
         /** @var \Concrete\Core\Permission\IPService $iph */
-        $iph = Core::make('helper/validation/ip');
+        $iph = $app->make('helper/validation/ip');
         $ip = $iph->getRequestIP();
         $db->query("update Users set uLastIP = ?, uLastLogin = ?, uPreviousLogin = ?, uNumLogins = uNumLogins + 1 where uID = ?", array(($ip === false) ? ('') : ($ip->getIp()), time(), $uLastLogin, $this->uID));
     }
 
     public function recordView($c)
     {
-        $db = Loader::db();
+        $app = Application::getFacadeApplication();
+        $db = $app['database']->connection();
+
         $uID = ($this->uID > 0) ? $this->uID : 0;
         $cID = $c->getCollectionID();
         $v = array($cID, $uID);
@@ -254,7 +268,9 @@ class User extends Object
     // Use only for checking password hashes, not generating new ones to store.
     public function legacyEncryptPassword($uPassword)
     {
-        return md5($uPassword . ':' . PASSWORD_SALT);
+        $app = Application::getFacadeApplication();
+
+        return md5($uPassword . ':' . $app['config']->get('concrete.user.password.legacy_salt'));
     }
 
     public function isActive()
@@ -269,7 +285,7 @@ class User extends Object
 
     public function getLastOnline()
     {
-        return $this->uLastOnline;
+        return isset($this->uLastOnline) ? $this->uLastOnline : null;
     }
 
     public function getUserName()
@@ -299,6 +315,9 @@ class User extends Object
 
     public function setAuthTypeCookie($authType)
     {
+        $app = Application::getFacadeApplication();
+        $config = $app['config'];
+
         $cookie = array($this->getUserID(),$authType);
         $at = AuthenticationType::getByHandle($authType);
         $cookie[] = $at->controller->buildHash($this);
@@ -307,21 +326,23 @@ class User extends Object
             implode(':', $cookie),
             time() + USER_FOREVER_COOKIE_LIFETIME,
             DIR_REL . '/',
-            Config::get('concrete.session.cookie.domain'),
-            Config::get('concrete.session.cookie.secure'),
-            Config::get('concrete.session.cookie.httponly')
+            $config->get('concrete.session.cookie.cookie_domain'),
+            $config->get('concrete.session.cookie.cookie_secure'),
+            $config->get('concrete.session.cookie.cookie_httponly')
         );
     }
 
     public function setLastAuthType(AuthenticationType $at)
     {
-        $db = Loader::db();
+        $app = Application::getFacadeApplication();
+        $db = $app['database']->connection();
         $db->Execute('UPDATE Users SET uLastAuthTypeID=? WHERE uID=?', array($at->getAuthenticationTypeID(), $this->getUserID()));
     }
 
     public function getLastAuthType()
     {
-        $db = Loader::db();
+        $app = Application::getFacadeApplication();
+        $db = $app['database']->connection();
         $id = $db->getOne('SELECT uLastAuthTypeID FROM Users WHERE uID=?', array($this->getUserID()));
 
         return intval($id);
@@ -337,42 +358,49 @@ class User extends Object
 
     public function logout($hard = true)
     {
+        $app = Application::getFacadeApplication();
+        $events = $app['director'];
+
         // First, we check to see if we have any collection in edit mode
         $this->unloadCollectionEdit();
         $this->unloadAuthenticationTypes();
 
         $this->invalidateSession($hard);
-        Events::dispatch('on_user_logout');
+        $events->dispatch('on_user_logout');
     }
 
     public function invalidateSession($hard = true)
     {
+        $app = Application::getFacadeApplication();
+        $session = $app['session'];
+
         // @todo remove this hard option if `Session::clear()` does what we need.
         if (!$hard) {
-            Session::clear();
+            $session->clear();
         } else {
-            Session::invalidate();
+            $session->invalidate();
         }
 
         if (isset($_COOKIE['ccmAuthUserHash']) && $_COOKIE['ccmAuthUserHash']) {
+            $config = $app['config'];
             setcookie("ccmAuthUserHash", "", 315532800, DIR_REL . '/',
-                      Config::get('concrete.session.cookie.domain'),
-                      Config::get('concrete.session.cookie.secure'),
-                      Config::get('concrete.session.cookie.httponly'));
+                      $config->get('concrete.session.cookie.cookie_domain'),
+                      $config->get('concrete.session.cookie.cookie_secure'),
+                      $config->get('concrete.session.cookie.cookie_httponly'));
         }
     }
 
     public static function verifyAuthTypeCookie()
     {
-        if ($_COOKIE['ccmAuthUserHash']) {
-            list($_uID, $authType, $uHash) = explode(':', $_COOKIE['ccmAuthUserHash']);
+        if ($cookie = array_get($_COOKIE, 'ccmAuthUserHash')) {
+            list($_uID, $authType, $uHash) = explode(':', $cookie);
             $at = AuthenticationType::getByHandle($authType);
-            $u = User::getByUserID($_uID);
+            $u = self::getByUserID($_uID);
             if ((!is_object($u)) || $u->isError()) {
                 return;
             }
             if ($at->controller->verifyHash($u, $uHash)) {
-                User::loginByUserID($_uID);
+                self::loginByUserID($_uID);
             }
         }
     }
@@ -395,9 +423,12 @@ class User extends Object
      */
     public function setUserDefaultLanguage($lang)
     {
-        $db = Loader::db();
+        $app = Application::getFacadeApplication();
+        $db = $app['database']->connection();
+        $session = $app['session'];
+
         $this->uDefaultLanguage = $lang;
-        Session::set('uDefaultLanguage', $lang);
+        $session->set('uDefaultLanguage', $lang);
         $db->Execute('update Users set uDefaultLanguage = ? where uID = ?', array($lang, $this->getUserID()));
     }
 
@@ -423,16 +454,22 @@ class User extends Object
      */
     public function getUserLanguageToDisplay()
     {
+
         if ($this->getUserDefaultLanguage() != '') {
             return $this->getUserDefaultLanguage();
         } else {
-            return Config::get('concrete.locale');
+            $app = Application::getFacadeApplication();
+            $config = $app['config'];
+
+            return $config->get('concrete.locale');
         }
     }
 
     public function refreshUserGroups()
     {
-        $session = Core::make('session');
+        $app = Application::getFacadeApplication();
+        $session = $app['session'];
+
         $session->remove('uGroups');
         $session->remove('accessEntities');
         $ug = $this->_getUserGroups();
@@ -442,19 +479,22 @@ class User extends Object
 
     public function getUserAccessEntityObjects()
     {
+        $app = Application::getFacadeApplication();
         $req = Request::getInstance();
+        $session = $app['session'];
+
         if ($req->hasCustomRequestUser()) {
             // we bypass session-saving performance
             // and we don't save them in session.
             return PermissionAccessEntity::getForUser($this);
         }
 
-        if (Session::has('accessEntities')) {
-            $entities = Session::get('accessEntities');
+        if ($session->has('accessEntities')) {
+            $entities = $session->get('accessEntities');
         } else {
             $entities = PermissionAccessEntity::getForUser($this);
-            Session::set('accessEntities', $entities);
-            Session::set('accessEntitiesUpdated', time());
+            $session->set('accessEntities', $entities);
+            $session->set('accessEntitiesUpdated', time());
         }
 
         return $entities;
@@ -462,11 +502,14 @@ class User extends Object
 
     public function _getUserGroups($disableLogin = false)
     {
+        $app = Application::getFacadeApplication();
         $req = Request::getInstance();
-        if ((Session::has('uGroups')) && (!$disableLogin) && (!$req->hasCustomRequestUser())) {
-            $ug = Session::get('uGroups');
+        $session = $app['session'];
+
+        if (($session->has('uGroups')) && (!$disableLogin) && (!$req->hasCustomRequestUser())) {
+            $ug = $session->get('uGroups');
         } else {
-            $db = Loader::db();
+            $db = $app['database']->connection();
             if ($this->uID) {
                 $ug[REGISTERED_GROUP_ID] = REGISTERED_GROUP_ID;
 
@@ -493,13 +536,15 @@ class User extends Object
 
     public function enterGroup($g)
     {
+        $app = Application::getFacadeApplication();
         // takes a group object, and, if the user is not already in the group, it puts them into it
-        $dt = Loader::helper('date');
+        $dt = $app->make('helper/date');
 
         if (is_object($g)) {
             if (!$this->inGroup($g)) {
                 $gID = $g->getGroupID();
-                $db = Loader::db();
+                $db = $app['database']->connection();
+
                 $db->Replace('UserGroups', array(
                     'uID' => $this->getUserID(),
                     'gID' => $g->getGroupID(),
@@ -513,12 +558,12 @@ class User extends Object
                         $action->addDetailedEntry($this, $g);
                     }
 
-                    $mh = Loader::helper('mail');
-                    $ui = CoreUserInfo::getByID($this->getUserID());
+                    $mh = $app->make('mail');
+                    $ui = UserInfo::getByID($this->getUserID());
                     $mh->addParameter('badgeName', $g->getGroupDisplayName(false));
                     $mh->addParameter('uDisplayName', $ui->getUserDisplayName());
-                    $mh->addParameter('uProfileURL', View::url('/members/profile', 'view', $this->getUserID()));
-                    $mh->addParameter('siteName', Config::get('concrete.site'));
+                    $mh->addParameter('uProfileURL', (string) $ui->getUserPublicProfileURL());
+                    $mh->addParameter('siteName', $app['config']->get('concrete.site'));
                     $mh->to($ui->getUserEmail());
                     $mh->load('won_badge');
                     $mh->sendMail();
@@ -526,30 +571,36 @@ class User extends Object
 
                 $ue = new \Concrete\Core\User\Event\UserGroup($this);
                 $ue->setGroupObject($g);
-                Events::dispatch('on_user_enter_group', $ue);
+
+                $app['director']->dispatch('on_user_enter_group', $ue);
             }
         }
     }
 
     public function exitGroup($g)
     {
+
         // takes a group object, and, if the user is in the group, they exit the group
         if (is_object($g)) {
+            $app = Application::getFacadeApplication();
+            $db = $app['database']->connection();
+
             $gID = $g->getGroupID();
-            $db = Loader::db();
 
             $ue = new \Concrete\Core\User\Event\UserGroup($this);
             $ue->setGroupObject($g);
-            Events::dispatch('on_user_exit_group', $ue);
+            $app['director']->dispatch('on_user_exit_group', $ue);
 
-            $q = "delete from UserGroups where uID = '{$this->uID}' and gID = '{$gID}'";
-            $r = $db->query($q);
+            $q = 'delete from UserGroups where uID = ? and gID = ?';
+            $r = $db->executeQuery($q, array($this->uID, $gID));
         }
     }
 
     public function inGroup($g)
     {
-        $db = Loader::db();
+        $app = Application::getFacadeApplication();
+        $db = $app['database']->connection();
+
         $v = array($this->uID, $g->getGroupID());
         $cnt = $db->GetOne("select gID from UserGroups where uID = ? and gID = ?", $v);
 
@@ -558,10 +609,12 @@ class User extends Object
 
     public function loadMasterCollectionEdit($mcID, $ocID)
     {
+        $app = Application::getFacadeApplication();
+        $session = $app['session'];
         // basically, this function loads the master collection ID you're working on into session
         // so you can work on it without the system failing because you're editing a template
-        Session::set('mcEditID', $mcID);
-        Session::set('ocID', $ocID);
+        $session->set('mcEditID', $mcID);
+        $session->set('ocID', $ocID);
     }
 
     public function loadCollectionEdit(&$c)
@@ -573,22 +626,24 @@ class User extends Object
             return false;
         }
 
-        $db = Loader::db();
+        $app = Application::getFacadeApplication();
+        $db = $app['database']->connection();
+
         $cID = $c->getCollectionID();
         // first, we check to see if we have a collection in edit mode. If we do, we relinquish it
         $this->unloadCollectionEdit(false);
 
-        $q = "select cIsCheckedOut, cCheckedOutDatetime from Pages where cID = '{$cID}'";
-        $r = $db->query($q);
+        $q = 'select cIsCheckedOut, cCheckedOutDatetime from Pages where cID = ?';
+        $r = $db->executeQuery($q, array($cID));
         if ($r) {
             $row = $r->fetchRow();
             if (!$row['cIsCheckedOut']) {
-                Session::set('editCID', $cID);
+                $app['session']->set('editCID', $cID);
                 $uID = $this->getUserID();
-                $dh = Loader::helper('date');
+                $dh = $app->make('helper/date');
                 $datetime = $dh->getOverridableNow();
-                $q2 = "update Pages set cIsCheckedOut = 1, cCheckedOutUID = '{$uID}', cCheckedOutDatetime = '{$datetime}', cCheckedOutDatetimeLastEdit = '{$datetime}' where cID = '{$cID}'";
-                $r2 = $db->query($q2);
+                $q2 = 'update Pages set cIsCheckedOut = ?, cCheckedOutUID = ?, cCheckedOutDatetime = ?, cCheckedOutDatetimeLastEdit = ? where cID = ?';
+                $r2 = $db->executeQuery($q2, array(1, $uID, $datetime, $datetime, $cID));
 
                 $c->cIsCheckedOut = 1;
                 $c->cCheckedOutUID = $uID;
@@ -600,10 +655,11 @@ class User extends Object
 
     public function unloadCollectionEdit($removeCache = true)
     {
-        // first we remove the cached versions of all of these pages
-        $db = Loader::db();
+        $app = Application::getFacadeApplication();
+        $db = $app['database']->connection();
+
         if ($this->getUserID() > 0) {
-            $col = $db->GetCol("select cID from Pages where cCheckedOutUID = " . $this->getUserID());
+            $col = $db->GetCol('select cID from Pages where cCheckedOutUID = ?', array($this->getUserID()));
             foreach ($col as $cID) {
                 $p = Page::getByID($cID);
                 if ($removeCache) {
@@ -619,7 +675,9 @@ class User extends Object
     public function config($cfKey)
     {
         if ($this->isRegistered()) {
-            $db = Loader::db();
+            $app = Application::getFacadeApplication();
+            $db = $app['database']->connection();
+
             $val = $db->GetOne("select cfValue from ConfigStore where uID = ? and cfKey = ?", array($this->getUserID(), $cfKey));
 
             return $val;
@@ -628,31 +686,35 @@ class User extends Object
 
     public function markPreviousFrontendPage(Page $c)
     {
-        Session::set('frontendPreviousPageID', $c->getCollectionID());
+        $app = Application::getFacadeApplication();
+        $app['session']->set('frontendPreviousPageID', $c->getCollectionID());
     }
 
     public function getPreviousFrontendPageID()
     {
-        return Session::get('frontendPreviousPageID');
+        $app = Application::getFacadeApplication();
+        return $app['session']->get('frontendPreviousPageID');
     }
 
     public function saveConfig($cfKey, $cfValue)
     {
-        $db = Loader::db();
-        $db->Replace('ConfigStore', array('cfKey' => $cfKey, 'cfValue' => $cfValue, 'uID' => $this->getUserID()), array('cfKey', 'uID'), true);
+        $app = Application::getFacadeApplication();
+        $app['database']->connection()->Replace('ConfigStore', array('cfKey' => $cfKey, 'cfValue' => $cfValue, 'uID' => $this->getUserID()), array('cfKey', 'uID'), true);
     }
 
     public function refreshCollectionEdit(&$c)
     {
         if ($this->isLoggedIn() && $c->getCollectionCheckedOutUserID() == $this->getUserID()) {
-            $db = Loader::db();
+
+            $app = Application::getFacadeApplication();
+            $db = $app['database']->connection();
             $cID = $c->getCollectionID();
 
-            $dh = Loader::helper('date');
+            $dh = $app->make('helper/date');
             $datetime = $dh->getOverridableNow();
 
-            $q = "update Pages set cCheckedOutDatetimeLastEdit = '{$datetime}' where cID = '{$cID}'";
-            $r = $db->query($q);
+            $q = 'update Pages set cCheckedOutDatetimeLastEdit = ? where cID = ?';
+            $r = $db->executeQuery($q, array($datetime, $cID));
 
             $c->cCheckedOutDatetimeLastEdit = $datetime;
         }
@@ -661,7 +723,9 @@ class User extends Object
     public function forceCollectionCheckInAll()
     {
         // This function forces checkin to take place
-        $db = Loader::db();
+        $app = Application::getFacadeApplication();
+        $db = $app['database']->connection();
+
         $q = "update Pages set cIsCheckedOut = 0, cCheckedOutUID = null, cCheckedOutDatetime = null, cCheckedOutDatetimeLastEdit = null";
         $r = $db->query($q);
 
@@ -675,10 +739,14 @@ class User extends Object
      */
     public function getUserPasswordHasher()
     {
+        $app = Application::getFacadeApplication();
+        $config = $app['config'];
         if (isset($this->hasher)) {
             return $this->hasher;
         }
-        $this->hasher = new PasswordHash(Config::get('concrete.user.password.hash_cost_log2'), Config::get('concrete.user.password.hash_portable'));
+        $this->hasher = new PasswordHash(
+            $config->get('concrete.user.password.hash_cost_log2'),
+            $config->get('concrete.user.password.hash_portable'));
 
         return $this->hasher;
     }
@@ -690,10 +758,13 @@ class User extends Object
      */
     public function persist($cache_interface = true)
     {
+
         $this->refreshUserGroups();
 
-        /** @var Session $session */
-        $session = Core::make('session');
+        $app = Application::getFacadeApplication();
+
+        /** @var \Symfony\Component\HttpFoundation\Session\Session $session */
+        $session = $app['session'];
         $session->set('uID', $this->getUserID());
         $session->set('uName', $this->getUserName());
         $session->set('uBlockTypesSet', false);
@@ -704,7 +775,7 @@ class User extends Object
         $session->set('uLastPasswordChange', $this->getLastPasswordChange());
 
         if ($cache_interface) {
-            Loader::helper('concrete/ui')->cacheInterfaceItems();
+            $app->make('helper/concrete/ui')->cacheInterfaceItems();
         }
     }
 
