@@ -5,7 +5,7 @@
     <meta http-equiv="X-UA-Compatible" content="IE=edge">
     <link rel="stylesheet" type="text/css" href="<?php echo $view->getThemePath()?>/css/bootstrap-modified.css">
     <?php echo $html->css($view->getStylesheet('main.less'))?>
-    <?php Loader::element('header_required', array('pageTitle' => $pageTitle));?>
+    <?php Loader::element('header_required', array('pageTitle' => isset($pageTitle) ? $pageTitle : '', 'pageDescription' => isset($pageDescription) ? $pageDescription : ''));?>
     <meta name="viewport" content="width=device-width, initial-scale=1.0">
     <script>
         if (navigator.userAgent.match(/IEMobile\/10\.0/)) {
